pub struct AngularAcceleration { /* private fields */ }Trait Implementations
Sourceimpl Add for AngularAcceleration
impl Add for AngularAcceleration
Sourceimpl AddAssign for AngularAcceleration
impl AddAssign for AngularAcceleration
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Clone for AngularAcceleration
impl Clone for AngularAcceleration
Sourcefn clone(&self) -> AngularAcceleration
fn clone(&self) -> AngularAcceleration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AngularAcceleration
impl Debug for AngularAcceleration
Sourceimpl Display for AngularAcceleration
impl Display for AngularAcceleration
Sourceimpl Div<AngularAcceleration> for AngularVelocity
impl Div<AngularAcceleration> for AngularVelocity
Sourceimpl Div<f64> for AngularAcceleration
impl Div<f64> for AngularAcceleration
Sourceimpl Div for AngularAcceleration
impl Div for AngularAcceleration
Sourceimpl DivArray1<AngularAcceleration> for Array1<AngularVelocity>
impl DivArray1<AngularAcceleration> for Array1<AngularVelocity>
Sourceimpl DivArray2<AngularAcceleration> for Array2<AngularVelocity>
impl DivArray2<AngularAcceleration> for Array2<AngularVelocity>
Sourceimpl DivAssign<f64> for AngularAcceleration
impl DivAssign<f64> for AngularAcceleration
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl From<f64> for AngularAcceleration
impl From<f64> for AngularAcceleration
Sourceimpl FromPrimitive for AngularAcceleration
impl FromPrimitive for AngularAcceleration
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<AngularAcceleration> for Time
impl Mul<AngularAcceleration> for Time
Sourcetype Output = AngularVelocity
type Output = AngularVelocity
The resulting type after applying the
* operator.Sourceimpl Mul<AngularAcceleration> for f64
impl Mul<AngularAcceleration> for f64
Sourcetype Output = AngularAcceleration
type Output = AngularAcceleration
The resulting type after applying the
* operator.Sourceimpl Mul<Time> for AngularAcceleration
impl Mul<Time> for AngularAcceleration
Sourceimpl Mul<f64> for AngularAcceleration
impl Mul<f64> for AngularAcceleration
Sourceimpl MulArray1<AngularAcceleration> for Array1<Time>
impl MulArray1<AngularAcceleration> for Array1<Time>
type Output = ArrayBase<OwnedRepr<AngularVelocity>, Dim<[usize; 1]>>
fn mul_array1(self, rhs: Array1<AngularAcceleration>) -> Array1<AngularVelocity>
Sourceimpl MulArray2<AngularAcceleration> for Array2<Time>
impl MulArray2<AngularAcceleration> for Array2<Time>
type Output = ArrayBase<OwnedRepr<AngularVelocity>, Dim<[usize; 2]>>
fn mul_array2( self, rhs: Array2<AngularAcceleration>, ) -> Result<Array2<AngularVelocity>, String>
Sourceimpl MulAssign<f64> for AngularAcceleration
impl MulAssign<f64> for AngularAcceleration
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl Neg for AngularAcceleration
impl Neg for AngularAcceleration
Sourceimpl PartialEq for AngularAccelerationwhere
AngularAcceleration: PhysicsQuantity,
impl PartialEq for AngularAccelerationwhere
AngularAcceleration: PhysicsQuantity,
Sourceimpl PartialOrd for AngularAccelerationwhere
AngularAcceleration: PhysicsQuantity,
impl PartialOrd for AngularAccelerationwhere
AngularAcceleration: PhysicsQuantity,
Sourceimpl PhysicsQuantity for AngularAcceleration
impl PhysicsQuantity for AngularAcceleration
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = AngularAccelerationUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> AngularAcceleration
fn split_value(v: f64) -> (f64, i32)
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn is_nan(&self) -> bool
fn from_raw(value: f64) -> Self
fn nan() -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl Sub for AngularAcceleration
impl Sub for AngularAcceleration
Sourceimpl SubAssign for AngularAcceleration
impl SubAssign for AngularAcceleration
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreSourceimpl Zero for AngularAcceleration
impl Zero for AngularAcceleration
impl Copy for AngularAcceleration
impl UnitforgeQuantity for AngularAcceleration