pub struct Area { /* private fields */ }Trait Implementations
Sourceimpl AddAssign for Area
impl AddAssign for Area
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Div<Area> for AreaOfMoment
impl Div<Area> for AreaOfMoment
Sourceimpl Div<Area> for MassPerTimeSquare
impl Div<Area> for MassPerTimeSquare
Sourceimpl Div<AreaOfMoment> for Area
impl Div<AreaOfMoment> for Area
Sourcetype Output = InverseArea
type Output = InverseArea
The resulting type after applying the
/ operator.Sourceimpl Div<InverseArea> for Area
impl Div<InverseArea> for Area
Sourcetype Output = AreaOfMoment
type Output = AreaOfMoment
The resulting type after applying the
/ operator.Sourceimpl Div<InverseDistance> for Area
impl Div<InverseDistance> for Area
Sourceimpl DivAssign<f64> for Area
impl DivAssign<f64> for Area
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl FromPrimitive for Area
impl FromPrimitive for Area
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<Area> for ForcePerVolume
impl Mul<Area> for ForcePerVolume
Sourceimpl Mul<Area> for InverseArea
impl Mul<Area> for InverseArea
Sourceimpl Mul<Area> for InverseDistance
impl Mul<Area> for InverseDistance
Sourceimpl Mul<ForcePerVolume> for Area
impl Mul<ForcePerVolume> for Area
Sourcetype Output = MassPerTimeSquare
type Output = MassPerTimeSquare
The resulting type after applying the
* operator.Sourceimpl Mul<InverseArea> for Area
impl Mul<InverseArea> for Area
Sourceimpl Mul<InverseDistance> for Area
impl Mul<InverseDistance> for Area
Sourceimpl MulAssign<f64> for Area
impl MulAssign<f64> for Area
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl PartialOrd for Areawhere
Area: PhysicsQuantity,
impl PartialOrd for Areawhere
Area: PhysicsQuantity,
Sourceimpl PhysicsQuantity for Area
impl PhysicsQuantity for Area
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = AreaUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> Area
fn split_value(v: f64) -> (f64, i32)
fn zero() -> Self
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn from_raw(value: f64) -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl SubAssign for Area
impl SubAssign for Area
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreimpl Copy for Area