pub struct Compliance { /* private fields */ }Trait Implementations
Sourceimpl Add for Compliance
impl Add for Compliance
Sourceimpl AddAssign for Compliance
impl AddAssign for Compliance
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Clone for Compliance
impl Clone for Compliance
Sourcefn clone(&self) -> Compliance
fn clone(&self) -> Compliance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Compliance
impl Debug for Compliance
Sourceimpl Display for Compliance
impl Display for Compliance
Sourceimpl Div<Compliance> for Distance
impl Div<Compliance> for Distance
Sourceimpl Div<Compliance> for Volume
impl Div<Compliance> for Volume
Sourceimpl Div<f64> for Compliance
impl Div<f64> for Compliance
Sourceimpl Div for Compliance
impl Div for Compliance
Sourceimpl DivAssign<f64> for Compliance
impl DivAssign<f64> for Compliance
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl From<f64> for Compliance
impl From<f64> for Compliance
Sourceimpl FromPrimitive for Compliance
impl FromPrimitive for Compliance
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<Compliance> for Force
impl Mul<Compliance> for Force
Sourceimpl Mul<Compliance> for ForceArea
impl Mul<Compliance> for ForceArea
Sourceimpl Mul<Compliance> for f64
impl Mul<Compliance> for f64
Sourcetype Output = Compliance
type Output = Compliance
The resulting type after applying the
* operator.Sourceimpl Mul<Force> for Compliance
impl Mul<Force> for Compliance
Sourceimpl Mul<ForceArea> for Compliance
impl Mul<ForceArea> for Compliance
Sourceimpl Mul<f64> for Compliance
impl Mul<f64> for Compliance
Sourceimpl MulAssign<f64> for Compliance
impl MulAssign<f64> for Compliance
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl Neg for Compliance
impl Neg for Compliance
Sourceimpl PartialEq for Compliancewhere
Compliance: PhysicsQuantity,
impl PartialEq for Compliancewhere
Compliance: PhysicsQuantity,
Sourceimpl PartialOrd for Compliancewhere
Compliance: PhysicsQuantity,
impl PartialOrd for Compliancewhere
Compliance: PhysicsQuantity,
Sourceimpl PhysicsQuantity for Compliance
impl PhysicsQuantity for Compliance
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = ComplianceUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> Compliance
fn split_value(v: f64) -> (f64, i32)
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn is_nan(&self) -> bool
fn from_raw(value: f64) -> Self
fn nan() -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl Sub for Compliance
impl Sub for Compliance
Sourceimpl SubAssign for Compliance
impl SubAssign for Compliance
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreSourceimpl Zero for Compliance
impl Zero for Compliance
impl Copy for Compliance
impl UnitforgeQuantity for Compliance