pub struct ForceArea { /* private fields */ }Trait Implementations
Sourceimpl AddAssign for ForceArea
impl AddAssign for ForceArea
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Div<AreaOfMoment> for ForceArea
impl Div<AreaOfMoment> for ForceArea
Sourceimpl Div<ForceArea> for ForceVolume
impl Div<ForceArea> for ForceVolume
Sourceimpl DivAssign<f64> for ForceArea
impl DivAssign<f64> for ForceArea
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl FromPrimitive for ForceArea
impl FromPrimitive for ForceArea
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<Compliance> for ForceArea
impl Mul<Compliance> for ForceArea
Sourceimpl Mul<ForceArea> for Compliance
impl Mul<ForceArea> for Compliance
Sourceimpl MulAssign<f64> for ForceArea
impl MulAssign<f64> for ForceArea
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl PartialOrd for ForceAreawhere
ForceArea: PhysicsQuantity,
impl PartialOrd for ForceAreawhere
ForceArea: PhysicsQuantity,
Sourceimpl PhysicsQuantity for ForceArea
impl PhysicsQuantity for ForceArea
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = ForceAreaUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> ForceArea
fn split_value(v: f64) -> (f64, i32)
fn zero() -> Self
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn from_raw(value: f64) -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl SubAssign for ForceArea
impl SubAssign for ForceArea
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreimpl Copy for ForceArea