pub struct ForceDistance { /* private fields */ }Trait Implementations
Sourceimpl Add for ForceDistance
impl Add for ForceDistance
Sourceimpl AddAssign for ForceDistance
impl AddAssign for ForceDistance
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Clone for ForceDistance
impl Clone for ForceDistance
Sourcefn clone(&self) -> ForceDistance
fn clone(&self) -> ForceDistance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForceDistance
impl Debug for ForceDistance
Sourceimpl Display for ForceDistance
impl Display for ForceDistance
Sourceimpl Div<Charge> for ForceDistance
impl Div<Charge> for ForceDistance
Sourceimpl Div<Distance> for ForceDistance
impl Div<Distance> for ForceDistance
Sourceimpl Div<Force> for ForceDistance
impl Div<Force> for ForceDistance
Sourceimpl Div<Mass> for ForceDistance
impl Div<Mass> for ForceDistance
Sourceimpl Div<Stress> for ForceDistance
impl Div<Stress> for ForceDistance
Sourceimpl Div<VelocitySquared> for ForceDistance
impl Div<VelocitySquared> for ForceDistance
Sourceimpl Div<Voltage> for ForceDistance
impl Div<Voltage> for ForceDistance
Sourceimpl Div<Volume> for ForceDistance
impl Div<Volume> for ForceDistance
Sourceimpl Div<f64> for ForceDistance
impl Div<f64> for ForceDistance
Sourceimpl Div for ForceDistance
impl Div for ForceDistance
Sourceimpl DivAssign<f64> for ForceDistance
impl DivAssign<f64> for ForceDistance
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl From<f64> for ForceDistance
impl From<f64> for ForceDistance
Sourceimpl FromPrimitive for ForceDistance
impl FromPrimitive for ForceDistance
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<Distance> for ForceDistance
impl Mul<Distance> for ForceDistance
Sourceimpl Mul<ForceDistance> for Distance
impl Mul<ForceDistance> for Distance
Sourceimpl Mul<ForceDistance> for InverseDistance
impl Mul<ForceDistance> for InverseDistance
Sourceimpl Mul<ForceDistance> for f64
impl Mul<ForceDistance> for f64
Sourcetype Output = ForceDistance
type Output = ForceDistance
The resulting type after applying the
* operator.Sourceimpl Mul<InverseDistance> for ForceDistance
impl Mul<InverseDistance> for ForceDistance
Sourceimpl Mul<f64> for ForceDistance
impl Mul<f64> for ForceDistance
Sourceimpl MulArray1<ForceDistance> for Array1<InverseDistance>
impl MulArray1<ForceDistance> for Array1<InverseDistance>
Sourceimpl MulArray2<ForceDistance> for Array2<InverseDistance>
impl MulArray2<ForceDistance> for Array2<InverseDistance>
Sourceimpl MulAssign<f64> for ForceDistance
impl MulAssign<f64> for ForceDistance
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl Neg for ForceDistance
impl Neg for ForceDistance
Sourceimpl PartialEq for ForceDistancewhere
ForceDistance: PhysicsQuantity,
impl PartialEq for ForceDistancewhere
ForceDistance: PhysicsQuantity,
Sourceimpl PartialOrd for ForceDistancewhere
ForceDistance: PhysicsQuantity,
impl PartialOrd for ForceDistancewhere
ForceDistance: PhysicsQuantity,
Sourceimpl PhysicsQuantity for ForceDistance
impl PhysicsQuantity for ForceDistance
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = ForceDistanceUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> ForceDistance
fn split_value(v: f64) -> (f64, i32)
fn zero() -> Self
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn from_raw(value: f64) -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
Sourceimpl Sub for ForceDistance
impl Sub for ForceDistance
Sourceimpl SubAssign for ForceDistance
impl SubAssign for ForceDistance
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreSourceimpl Zero for ForceDistance
impl Zero for ForceDistance
impl Copy for ForceDistance