pub struct MassPerDistance { /* private fields */ }Trait Implementations
Sourceimpl Add for MassPerDistance
impl Add for MassPerDistance
Sourceimpl AddAssign for MassPerDistance
impl AddAssign for MassPerDistance
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Clone for MassPerDistance
impl Clone for MassPerDistance
Sourcefn clone(&self) -> MassPerDistance
fn clone(&self) -> MassPerDistance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MassPerDistance
impl Debug for MassPerDistance
Sourceimpl Display for MassPerDistance
impl Display for MassPerDistance
Sourceimpl Div<Area> for MassPerDistance
impl Div<Area> for MassPerDistance
Sourceimpl Div<Density> for MassPerDistance
impl Div<Density> for MassPerDistance
Sourceimpl Div<MassPerDistance> for Mass
impl Div<MassPerDistance> for Mass
Sourceimpl Div<MassPerDistance> for Stiffness
impl Div<MassPerDistance> for Stiffness
Sourcetype Output = Acceleration
type Output = Acceleration
The resulting type after applying the
/ operator.Sourceimpl Div<f64> for MassPerDistance
impl Div<f64> for MassPerDistance
Sourceimpl Div for MassPerDistance
impl Div for MassPerDistance
Sourceimpl DivArray1<MassPerDistance> for Array1<Stiffness>
impl DivArray1<MassPerDistance> for Array1<Stiffness>
type Output = ArrayBase<OwnedRepr<Acceleration>, Dim<[usize; 1]>>
fn div_array1(self, rhs: Array1<MassPerDistance>) -> Array1<Acceleration>
Sourceimpl DivArray2<MassPerDistance> for Array2<Stiffness>
impl DivArray2<MassPerDistance> for Array2<Stiffness>
type Output = ArrayBase<OwnedRepr<Acceleration>, Dim<[usize; 2]>>
fn div_array2( self, rhs: Array2<MassPerDistance>, ) -> Result<Array2<Acceleration>, String>
Sourceimpl DivAssign<f64> for MassPerDistance
impl DivAssign<f64> for MassPerDistance
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl From<f64> for MassPerDistance
impl From<f64> for MassPerDistance
Sourceimpl FromPrimitive for MassPerDistance
impl FromPrimitive for MassPerDistance
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<Acceleration> for MassPerDistance
impl Mul<Acceleration> for MassPerDistance
Sourceimpl Mul<Distance> for MassPerDistance
impl Mul<Distance> for MassPerDistance
Sourceimpl Mul<MassPerDistance> for Acceleration
impl Mul<MassPerDistance> for Acceleration
Sourceimpl Mul<MassPerDistance> for Distance
impl Mul<MassPerDistance> for Distance
Sourceimpl Mul<MassPerDistance> for f64
impl Mul<MassPerDistance> for f64
Sourcetype Output = MassPerDistance
type Output = MassPerDistance
The resulting type after applying the
* operator.Sourceimpl Mul<f64> for MassPerDistance
impl Mul<f64> for MassPerDistance
Sourceimpl MulArray1<MassPerDistance> for Array1<Acceleration>
impl MulArray1<MassPerDistance> for Array1<Acceleration>
Sourceimpl MulArray2<MassPerDistance> for Array2<Acceleration>
impl MulArray2<MassPerDistance> for Array2<Acceleration>
Sourceimpl MulAssign<f64> for MassPerDistance
impl MulAssign<f64> for MassPerDistance
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl Neg for MassPerDistance
impl Neg for MassPerDistance
Sourceimpl PartialEq for MassPerDistancewhere
MassPerDistance: PhysicsQuantity,
impl PartialEq for MassPerDistancewhere
MassPerDistance: PhysicsQuantity,
Sourceimpl PartialOrd for MassPerDistancewhere
MassPerDistance: PhysicsQuantity,
impl PartialOrd for MassPerDistancewhere
MassPerDistance: PhysicsQuantity,
Sourceimpl PhysicsQuantity for MassPerDistance
impl PhysicsQuantity for MassPerDistance
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = MassPerDistanceUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> MassPerDistance
fn split_value(v: f64) -> (f64, i32)
fn zero() -> Self
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn from_raw(value: f64) -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl Sub for MassPerDistance
impl Sub for MassPerDistance
Sourceimpl SubAssign for MassPerDistance
impl SubAssign for MassPerDistance
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreSourceimpl Zero for MassPerDistance
impl Zero for MassPerDistance
impl Copy for MassPerDistance