pub struct RotationalStiffness { /* private fields */ }Trait Implementations
Sourceimpl Add for RotationalStiffness
impl Add for RotationalStiffness
Sourceimpl AddAssign for RotationalStiffness
impl AddAssign for RotationalStiffness
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Clone for RotationalStiffness
impl Clone for RotationalStiffness
Sourcefn clone(&self) -> RotationalStiffness
fn clone(&self) -> RotationalStiffness
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RotationalStiffness
impl Debug for RotationalStiffness
Sourceimpl Display for RotationalStiffness
impl Display for RotationalStiffness
Sourceimpl Div<RotationalStiffness> for ForceDistance
impl Div<RotationalStiffness> for ForceDistance
Sourceimpl Div<f64> for RotationalStiffness
impl Div<f64> for RotationalStiffness
Sourceimpl Div for RotationalStiffness
impl Div for RotationalStiffness
Sourceimpl DivArray1<RotationalStiffness> for Array1<ForceDistance>
impl DivArray1<RotationalStiffness> for Array1<ForceDistance>
Sourceimpl DivArray2<RotationalStiffness> for Array2<ForceDistance>
impl DivArray2<RotationalStiffness> for Array2<ForceDistance>
Sourceimpl DivAssign<f64> for RotationalStiffness
impl DivAssign<f64> for RotationalStiffness
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl From<f64> for RotationalStiffness
impl From<f64> for RotationalStiffness
Sourceimpl FromPrimitive for RotationalStiffness
impl FromPrimitive for RotationalStiffness
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<Angle> for RotationalStiffness
impl Mul<Angle> for RotationalStiffness
Sourceimpl Mul<RotationalStiffness> for Angle
impl Mul<RotationalStiffness> for Angle
Sourcetype Output = ForceDistance
type Output = ForceDistance
The resulting type after applying the
* operator.Sourceimpl Mul<RotationalStiffness> for f64
impl Mul<RotationalStiffness> for f64
Sourcetype Output = RotationalStiffness
type Output = RotationalStiffness
The resulting type after applying the
* operator.Sourceimpl Mul<f64> for RotationalStiffness
impl Mul<f64> for RotationalStiffness
Sourceimpl MulArray1<RotationalStiffness> for Array1<Angle>
impl MulArray1<RotationalStiffness> for Array1<Angle>
type Output = ArrayBase<OwnedRepr<ForceDistance>, Dim<[usize; 1]>>
fn mul_array1(self, rhs: Array1<RotationalStiffness>) -> Array1<ForceDistance>
Sourceimpl MulArray2<RotationalStiffness> for Array2<Angle>
impl MulArray2<RotationalStiffness> for Array2<Angle>
type Output = ArrayBase<OwnedRepr<ForceDistance>, Dim<[usize; 2]>>
fn mul_array2( self, rhs: Array2<RotationalStiffness>, ) -> Result<Array2<ForceDistance>, String>
Sourceimpl MulAssign<f64> for RotationalStiffness
impl MulAssign<f64> for RotationalStiffness
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl Neg for RotationalStiffness
impl Neg for RotationalStiffness
Sourceimpl PartialEq for RotationalStiffnesswhere
RotationalStiffness: PhysicsQuantity,
impl PartialEq for RotationalStiffnesswhere
RotationalStiffness: PhysicsQuantity,
Sourceimpl PartialOrd for RotationalStiffnesswhere
RotationalStiffness: PhysicsQuantity,
impl PartialOrd for RotationalStiffnesswhere
RotationalStiffness: PhysicsQuantity,
Sourceimpl PhysicsQuantity for RotationalStiffness
impl PhysicsQuantity for RotationalStiffness
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = RotationalStiffnessUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> RotationalStiffness
fn split_value(v: f64) -> (f64, i32)
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn is_nan(&self) -> bool
fn from_raw(value: f64) -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl Sub for RotationalStiffness
impl Sub for RotationalStiffness
Sourceimpl SubAssign for RotationalStiffness
impl SubAssign for RotationalStiffness
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreSourceimpl Zero for RotationalStiffness
impl Zero for RotationalStiffness
impl Copy for RotationalStiffness