pub struct StressSquared { /* private fields */ }Trait Implementations
Sourceimpl Add for StressSquared
impl Add for StressSquared
Sourceimpl AddAssign for StressSquared
impl AddAssign for StressSquared
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Clone for StressSquared
impl Clone for StressSquared
Sourcefn clone(&self) -> StressSquared
fn clone(&self) -> StressSquared
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StressSquared
impl Debug for StressSquared
Sourceimpl Display for StressSquared
impl Display for StressSquared
Sourceimpl Div<Stress> for StressSquared
impl Div<Stress> for StressSquared
Sourceimpl Div<f64> for StressSquared
impl Div<f64> for StressSquared
Sourceimpl Div for StressSquared
impl Div for StressSquared
Sourceimpl DivAssign<f64> for StressSquared
impl DivAssign<f64> for StressSquared
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl From<f64> for StressSquared
impl From<f64> for StressSquared
Sourceimpl FromPrimitive for StressSquared
impl FromPrimitive for StressSquared
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<StressSquared> for f64
impl Mul<StressSquared> for f64
Sourcetype Output = StressSquared
type Output = StressSquared
The resulting type after applying the
* operator.Sourceimpl Mul<f64> for StressSquared
impl Mul<f64> for StressSquared
Sourceimpl MulAssign<f64> for StressSquared
impl MulAssign<f64> for StressSquared
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl Neg for StressSquared
impl Neg for StressSquared
Sourceimpl PartialEq for StressSquaredwhere
StressSquared: PhysicsQuantity,
impl PartialEq for StressSquaredwhere
StressSquared: PhysicsQuantity,
Sourceimpl PartialOrd for StressSquaredwhere
StressSquared: PhysicsQuantity,
impl PartialOrd for StressSquaredwhere
StressSquared: PhysicsQuantity,
Sourceimpl PhysicsQuantity for StressSquared
impl PhysicsQuantity for StressSquared
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = StressSquaredUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> StressSquared
fn split_value(v: f64) -> (f64, i32)
fn zero() -> Self
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn from_raw(value: f64) -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl Sub for StressSquared
impl Sub for StressSquared
Sourceimpl SubAssign for StressSquared
impl SubAssign for StressSquared
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreSourceimpl Zero for StressSquared
impl Zero for StressSquared
impl Copy for StressSquared