pub struct Time { /* private fields */ }Trait Implementations
Sourceimpl AddAssign for Time
impl AddAssign for Time
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Div<Time> for AngularVelocity
impl Div<Time> for AngularVelocity
Sourceimpl DivAssign<f64> for Time
impl DivAssign<f64> for Time
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl FromPrimitive for Time
impl FromPrimitive for Time
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<Acceleration> for Time
impl Mul<Acceleration> for Time
Sourceimpl Mul<AngularAcceleration> for Time
impl Mul<AngularAcceleration> for Time
Sourcetype Output = AngularVelocity
type Output = AngularVelocity
The resulting type after applying the
* operator.Sourceimpl Mul<AngularVelocity> for Time
impl Mul<AngularVelocity> for Time
Sourceimpl Mul<Time> for Acceleration
impl Mul<Time> for Acceleration
Sourceimpl Mul<Time> for AngularAcceleration
impl Mul<Time> for AngularAcceleration
Sourceimpl Mul<Time> for AngularVelocity
impl Mul<Time> for AngularVelocity
Sourceimpl MulAssign<f64> for Time
impl MulAssign<f64> for Time
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl PartialOrd for Timewhere
Time: PhysicsQuantity,
impl PartialOrd for Timewhere
Time: PhysicsQuantity,
Sourceimpl PhysicsQuantity for Time
impl PhysicsQuantity for Time
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = TimeUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> Time
fn split_value(v: f64) -> (f64, i32)
fn zero() -> Self
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn from_raw(value: f64) -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl SubAssign for Time
impl SubAssign for Time
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreimpl Copy for Time