pub struct VelocitySquared { /* private fields */ }Trait Implementations
Sourceimpl Add for VelocitySquared
impl Add for VelocitySquared
Sourceimpl AddAssign for VelocitySquared
impl AddAssign for VelocitySquared
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Clone for VelocitySquared
impl Clone for VelocitySquared
Sourcefn clone(&self) -> VelocitySquared
fn clone(&self) -> VelocitySquared
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VelocitySquared
impl Debug for VelocitySquared
Sourceimpl Display for VelocitySquared
impl Display for VelocitySquared
Sourceimpl Div<VelocitySquared> for ForceDistance
impl Div<VelocitySquared> for ForceDistance
Sourceimpl Div<f64> for VelocitySquared
impl Div<f64> for VelocitySquared
Sourceimpl Div for VelocitySquared
impl Div for VelocitySquared
Sourceimpl DivArray1<VelocitySquared> for Array1<ForceDistance>
impl DivArray1<VelocitySquared> for Array1<ForceDistance>
Sourceimpl DivArray2<VelocitySquared> for Array2<ForceDistance>
impl DivArray2<VelocitySquared> for Array2<ForceDistance>
Sourceimpl DivAssign<f64> for VelocitySquared
impl DivAssign<f64> for VelocitySquared
Sourcefn div_assign(&mut self, rhs: f64)
fn div_assign(&mut self, rhs: f64)
Performs the
/= operation. Read moreSourceimpl From<f64> for VelocitySquared
impl From<f64> for VelocitySquared
Sourceimpl FromPrimitive for VelocitySquared
impl FromPrimitive for VelocitySquared
Sourcefn from_i64(n: i64) -> Option<Self>
fn from_i64(n: i64) -> Option<Self>
Converts an
i64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u64(n: u64) -> Option<Self>
fn from_u64(n: u64) -> Option<Self>
Converts an
u64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_f64(n: f64) -> Option<Self>
fn from_f64(n: f64) -> Option<Self>
Converts a
f64 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_isize(n: isize) -> Option<Self>
fn from_isize(n: isize) -> Option<Self>
Converts an
isize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i8(n: i8) -> Option<Self>
fn from_i8(n: i8) -> Option<Self>
Converts an
i8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i16(n: i16) -> Option<Self>
fn from_i16(n: i16) -> Option<Self>
Converts an
i16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i32(n: i32) -> Option<Self>
fn from_i32(n: i32) -> Option<Self>
Converts an
i32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_i128(n: i128) -> Option<Self>
fn from_i128(n: i128) -> Option<Self>
Converts an
i128 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned. Read moreSourcefn from_usize(n: usize) -> Option<Self>
fn from_usize(n: usize) -> Option<Self>
Converts a
usize to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u8(n: u8) -> Option<Self>
fn from_u8(n: u8) -> Option<Self>
Converts an
u8 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u16(n: u16) -> Option<Self>
fn from_u16(n: u16) -> Option<Self>
Converts an
u16 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourcefn from_u32(n: u32) -> Option<Self>
fn from_u32(n: u32) -> Option<Self>
Converts an
u32 to return an optional value of this type. If the
value cannot be represented by this type, then None is returned.Sourceimpl Mul<Mass> for VelocitySquared
impl Mul<Mass> for VelocitySquared
Sourceimpl Mul<VelocitySquared> for Mass
impl Mul<VelocitySquared> for Mass
Sourcetype Output = ForceDistance
type Output = ForceDistance
The resulting type after applying the
* operator.Sourceimpl Mul<VelocitySquared> for f64
impl Mul<VelocitySquared> for f64
Sourcetype Output = VelocitySquared
type Output = VelocitySquared
The resulting type after applying the
* operator.Sourceimpl Mul<f64> for VelocitySquared
impl Mul<f64> for VelocitySquared
Sourceimpl MulArray1<VelocitySquared> for Array1<Mass>
impl MulArray1<VelocitySquared> for Array1<Mass>
type Output = ArrayBase<OwnedRepr<ForceDistance>, Dim<[usize; 1]>>
fn mul_array1(self, rhs: Array1<VelocitySquared>) -> Array1<ForceDistance>
Sourceimpl MulArray2<VelocitySquared> for Array2<Mass>
impl MulArray2<VelocitySquared> for Array2<Mass>
type Output = ArrayBase<OwnedRepr<ForceDistance>, Dim<[usize; 2]>>
fn mul_array2( self, rhs: Array2<VelocitySquared>, ) -> Result<Array2<ForceDistance>, String>
Sourceimpl MulAssign<f64> for VelocitySquared
impl MulAssign<f64> for VelocitySquared
Sourcefn mul_assign(&mut self, rhs: f64)
fn mul_assign(&mut self, rhs: f64)
Performs the
*= operation. Read moreSourceimpl Neg for VelocitySquared
impl Neg for VelocitySquared
Sourceimpl PartialEq for VelocitySquaredwhere
VelocitySquared: PhysicsQuantity,
impl PartialEq for VelocitySquaredwhere
VelocitySquared: PhysicsQuantity,
Sourceimpl PartialOrd for VelocitySquaredwhere
VelocitySquared: PhysicsQuantity,
impl PartialOrd for VelocitySquaredwhere
VelocitySquared: PhysicsQuantity,
Sourceimpl PhysicsQuantity for VelocitySquared
impl PhysicsQuantity for VelocitySquared
const INFINITY: Self
const NEG_INFINITY: Self
type Unit = VelocitySquaredUnit
fn as_f64(&self) -> f64
fn new(value: f64, unit: Self::Unit) -> VelocitySquared
fn split_value(v: f64) -> (f64, i32)
fn zero() -> Self
fn get_power(&self) -> i32
fn get_multiplier(&self) -> f64
fn get_tuple(&self) -> (f64, i32)
fn to(&self, unit: Self::Unit) -> f64
fn abs(self) -> Self
fn from_raw(value: f64) -> Self
fn from_exponential(multiplier: f64, power: i32) -> Self
fn min(self, other: Self) -> Self
fn max(self, other: Self) -> Self
fn is_close(&self, other: &Self, tolerance: &Self) -> bool
fn optimize(&mut self)
Sourceimpl Sub for VelocitySquared
impl Sub for VelocitySquared
Sourceimpl SubAssign for VelocitySquared
impl SubAssign for VelocitySquared
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreSourceimpl Zero for VelocitySquared
impl Zero for VelocitySquared
impl Copy for VelocitySquared